.. :changelog:

History
-------

0.1.0 (2014)
++++++++++++++++++

* First release on PyPI.


0.2.0 (2014)
++++++++++++++++++

* Added support for ManyToMany fields in SIEVE_MODEL



0.3.0 (2014)
++++++++++++++++++

* Changed the mapping from User to Group, dealt with self-referencing models etc.